
def format_log_path(path: str):
    return f"[bold magenta]{path}[/bold magenta]"

def format_log_warning(string: str):
    return f"[bold yellow]{string}[/bold yellow]"

def format_log_error(string: str):
    return f"[bold red]{string}[/bold red]"